@@ -2,7 +2,7 @@
 # @Author: Anderson
 # @Date:   2019-11-11 17:42:18
 # @Last Modified by:   ander
-# @Last Modified time: 2020-03-03 13:51:10
+# @Last Modified time: 2020-04-09 17:48:57
 from openpyxl import Workbook
 import requests
 from bs4 import BeautifulSoup
@@ -40,6 +40,7 @@ class WebCrawlerBot(object):
 			'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.119 Safari/537.36',
 		}
 		self.weibo_hot_list = []
+		self.liepin_urls = {}
 
 	def set_cookie(self, cookie):
 		self.headers['cookie'] = cookie
@@ -87,7 +88,18 @@ class WebCrawlerBot(object):
 		return [hot_count, title, author, content, url]
 
 	def get_liepin(self, keyword, page):
-		url = f'https://www.liepin.com/zhaopin/?key={quote_plus(keyword)}&curPage={page}'
+		if keyword not in self.liepin_urls:
+			req = requests.get(
+				f'https://www.liepin.com/zhaopin/?sfrom=click-pc_homepage-centre_searchbox-search_new&d_sfrom=search_fp&key={quote_plus(keyword)}',
+				headers=self.headers)
+			soup = BeautifulSoup(req.text, 'lxml')
+			self.liepin_urls[keyword] = 'https://www.liepin.com'
+			self.liepin_urls[keyword] += '&d_curPage={d_curPage}'.join(soup.select('.pagerbar a')[3]['href'].split('&d_curPage='))
+			self.liepin_urls[keyword] = self.liepin_urls[keyword].split('&curPage=')[0] + '&curPage={curPage}'
+		if page > 0:
+			url = self.liepin_urls[keyword].format(d_curPage=page - 1, curPage=page)
+		else:
+			url = self.liepin_urls[keyword].format(d_curPage=page + 1, curPage=page)
 		req = requests.get(url, headers=self.headers)
 		soup = BeautifulSoup(req.text, 'lxml')
 		results = []
@@ -132,7 +144,7 @@ class WebCrawlerBot(object):
 	def download_image(self, url, filename, folder):
 		mkdir(folder)
 		req = requests.get(url)
-		with open(os.path.join(folder, f'{filename}'), 'wb') as f:
+		with open(os.path.join(folder, f'{validate_title(filename)}'), 'wb') as f:
 			f.write(req.content)
 
 
